@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Base;
 
 BEGIN {
-    $WWW::Google::Contacts::Base::VERSION = '0.12';
+    $WWW::Google::Contacts::Base::VERSION = '0.13';
 }
 
 use Moose;
@@ -106,38 +106,4 @@ around BUILDARGS => sub {
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
-
-=pod
-
-=head1 NAME
-
-WWW::Google::Contacts::Base
-
-=head1 VERSION
-
-version 0.12
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Magnus Erixzon <magnus@erixzon.com>
-
-=item *
-
-Fayland Lam <fayland@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Fayland Lam.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
 __END__
