@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::InternalTypes;
 
 BEGIN {
-    $WWW::Google::Contacts::InternalTypes::VERSION = '0.12';
+    $WWW::Google::Contacts::InternalTypes::VERSION = '0.13';
 }
 
 use MooseX::Types -declare => [
@@ -37,38 +37,3 @@ coerce When, from Str, via {
     require WWW::Google::Contacts::Type::When;
     WWW::Google::Contacts::Type::When->new( start_time => $_ );
 };
-
-__END__
-
-=pod
-
-=head1 NAME
-
-WWW::Google::Contacts::InternalTypes
-
-=head1 VERSION
-
-version 0.12
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Magnus Erixzon <magnus@erixzon.com>
-
-=item *
-
-Fayland Lam <fayland@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Fayland Lam.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
