@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Meta::Attribute::Trait::XmlField;
 
 BEGIN {
-    $WWW::Google::Contacts::Meta::Attribute::Trait::XmlField::VERSION = '0.12';
+    $WWW::Google::Contacts::Meta::Attribute::Trait::XmlField::VERSION = '0.13';
 }
 
 use Moose::Role;
@@ -36,7 +36,7 @@ no Moose::Role;
 package Moose::Meta::Attribute::Custom::Trait::XmlField;
 
 BEGIN {
-    $Moose::Meta::Attribute::Custom::Trait::XmlField::VERSION = '0.12';
+    $Moose::Meta::Attribute::Custom::Trait::XmlField::VERSION = '0.13';
 }
 
 sub register_implementation {
@@ -44,38 +44,3 @@ sub register_implementation {
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-WWW::Google::Contacts::Meta::Attribute::Trait::XmlField
-
-=head1 VERSION
-
-version 0.12
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Magnus Erixzon <magnus@erixzon.com>
-
-=item *
-
-Fayland Lam <fayland@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Fayland Lam.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
