@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Type::Jot;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Jot::VERSION = '0.12';
+    $WWW::Google::Contacts::Type::Jot::VERSION = '0.13';
 }
 
 use Moose;
@@ -17,7 +17,6 @@ has type => (
     traits    => ['XmlField'],
     xml_key   => 'rel',
     predicate => 'has_type',
-    coerce    => 1,
     required  => 1,
 );
 
@@ -33,38 +32,4 @@ has value => (
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
-
-=pod
-
-=head1 NAME
-
-WWW::Google::Contacts::Type::Jot
-
-=head1 VERSION
-
-version 0.12
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Magnus Erixzon <magnus@erixzon.com>
-
-=item *
-
-Fayland Lam <fayland@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Fayland Lam.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
 __END__
