@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Type::Rel;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Rel::VERSION = '0.12';
+    $WWW::Google::Contacts::Type::Rel::VERSION = '0.13';
 }
 
 use Moose;
@@ -30,7 +30,7 @@ has uri => (
 sub _build_name {
     my $self = shift;
     die "No URI" unless $self->uri;
-    unless ( $self->uri =~ m{\#(\.*)$} ) {
+    unless ( $self->uri =~ m{\#(.+)$} ) {
         die "Can't parse uri: " . $self->uri;
     }
     return $1;
@@ -49,38 +49,4 @@ sub to_xml_hashref {
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
-
-=pod
-
-=head1 NAME
-
-WWW::Google::Contacts::Type::Rel
-
-=head1 VERSION
-
-version 0.12
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Magnus Erixzon <magnus@erixzon.com>
-
-=item *
-
-Fayland Lam <fayland@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Fayland Lam.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
 __END__
